==> likewise-open5_5.0.3991.1.orig.tar.gz: likewise-open-5.0.3991.1/netlogon/server/api/globals.c <==
/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 * -*- mode: c, c-basic-offset: 4 -*- */

/*
 * Copyright Likewise Software    2004-2008
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.  You should have received a copy of the GNU General
 * Public License along with this program.  If not, see 
 * <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewisesoftware.com
 */

/*
 * Copyright (C) Likewise Software. All rights reserved.
 *
 * Module Name:
 *
 *        globals.c
 *
 * Abstract:
 *
 *        Likewise Site Manager
 * 
 *        Server API Globals
 *
 * Authors: Krishna Ganugapati (krishnag@likewisesoftware.com)
 *          Sriram Nambakam (snambakam@likewisesoftware.com)
 *          Brian Dunstan (bdunstan@likewisesoftware.com)
 * 
 */
#include "includes.h"

pthread_rwlock_t g_SiteMgrLock;

HANDLE ghEventLogItf = (HANDLE)NULL;
pthread_rwlock_t ghEventLogItf_rwlock;

pthread_rwlock_t gLWNetGlobalDataLock;

/*
 * Caching
 */
PSTR gpszLWNetCurrentSiteName = NULL;

const DWORD gdwLWNetCacheReaperTimeoutSecsMinimum = 5 * LWNET_SECONDS_IN_MINUTE;
const DWORD gdwLWNetCacheReaperTimeoutSecsDefault = 15 * LWNET_SECONDS_IN_MINUTE;
const DWORD gdwLWNetCacheReaperTimeoutSecsMaximum = 1 * LWNET_SECONDS_IN_DAY;
DWORD gdwLWNetCacheReaperTimeoutSecs              = 15 * LWNET_SECONDS_IN_MINUTE;

const DWORD gdwLWNetCacheEntryExpirySecsMinimum = 15 * LWNET_SECONDS_IN_MINUTE;
const DWORD gdwLWNetCacheEntryExpirySecsDefault = 2 * LWNET_SECONDS_IN_HOUR;
const DWORD gdwLWNetCacheEntryExpirySecsMaximum = 1 * LWNET_SECONDS_IN_DAY;
DWORD gdwLWNetCacheEntryExpirySecs              = 2 * LWNET_SECONDS_IN_HOUR;

const DWORD gdwLWNetCacheWriteRetryIntervalMilliseconds = 500;
const DWORD gdwLWNetCacheWriteRetryAttempts = 20;

pthread_t       gLWNetCacheReaperThread;
pthread_mutex_t gLWNetCacheReaperThreadLock      = PTHREAD_MUTEX_INITIALIZER;
pthread_cond_t  gLWNetCacheReaperThreadCondition = PTHREAD_COND_INITIALIZER;
pthread_t*      gpLWNetCacheReaperThread = NULL;


DWORD
LWNetSrvApiInit(
    PCSTR pszConfigFilePath
    )
{
    DWORD dwError = 0;
    
    pthread_rwlock_init(&ghEventLogItf_rwlock, NULL);
    
    LWNetSrvInitEventlogInterface();

    dwError = LWNetSrvParseConfigFile(pszConfigFilePath);
    BAIL_ON_LWNET_ERROR(dwError);

    dwError = LWNetCacheInitialize();
    BAIL_ON_LWNET_ERROR(dwError);

    //dwError = LWNetInitCacheReaper();
    //BAIL_ON_LWNET_ERROR(dwError);

error:
    return dwError;
}

DWORD
LWNetSrvApiShutdown(
    VOID
    )
{
    LWNetSrvShutdownEventlogInterface();
    
    return 0;
}

==> likewise-open_6.0.0.53010.orig.tar.gz: likewise-open-6.0.0.53010/netlogon/server/api/globals.c <==
/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 * -*- mode: c, c-basic-offset: 4 -*- */

/*
 * Copyright Likewise Software    2004-2008
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.  You should have received a copy of the GNU General
 * Public License along with this program.  If not, see 
 * <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewisesoftware.com
 */

/*
 * Copyright (C) Likewise Software. All rights reserved.
 *
 * Module Name:
 *
 *        globals.c
 *
 * Abstract:
 *
 *        Likewise Site Manager
 * 
 *        Server API Globals
 *
 * Authors: Krishna Ganugapati (krishnag@likewisesoftware.com)
 *          Sriram Nambakam (snambakam@likewisesoftware.com)
 *          Brian Dunstan (bdunstan@likewisesoftware.com)
 * 
 */
#include "includes.h"

DWORD
LWNetSrvApiInit(
    VOID
    )
{
    DWORD dwError = 0;
    
    LWNetSrvInitEventlogInterface();

    dwError = LWNetSrvReadRegistry();
    BAIL_ON_LWNET_ERROR(dwError);

    dwError = LWNetCacheInitialize();
    BAIL_ON_LWNET_ERROR(dwError);

    dwError = LWNetInitializePlugin(LWNetConfigGetPluginPath());
    BAIL_ON_LWNET_ERROR(dwError);

error:
    return dwError;
}

DWORD
LWNetSrvApiShutdown(
    VOID
    )
{
    LWNetCleanupPlugin();

    LWNetCacheCleanup();

    LWNetSrvShutdownEventlogInterface();
    
    return 0;
}
